1.0.0 API documentation: GLM_EXT_vector_bool1_precision

| 1.0.0 API documentation

Typedefs
GLM_EXT_vector_bool1_precision
Stable extensions

## Typedefs
typedef vec< 1, bool, highp > | highp_bvec1
| 1 component vector of bool values.
typedef vec< 1, bool, lowp > | lowp_bvec1
| 1 component vector of bool values.
typedef vec< 1, bool, mediump > | mediump_bvec1
| 1 component vector of bool values.

## Detailed Description

Exposes highp_bvec1, mediump_bvec1 and lowp_bvec1 types.

Include <glm/ext/vector_bool1_precision.hpp> to use the features of this extension.